@@ -10,6 +10,9 @@ if 'svn' in sys.modules:
 # in order to know which functions/constants to emulate
 from svnmock import *
 
+# We need a default dispatcher
+import svnmock.mock
+
 # Take over the svn.* namespace so that modules calling that code
 # get redirected to us
 sys.modules['svn'] = sys.modules['svnmock']
