@@ -429,14 +429,7 @@ class Sequence(Container):
 	def _thaw(cls, frozen_state):
 		return cls([s.thaw() for s in frozen_state])
 
-class MockSession(Sequence):
-	def __init__(self):
-		global active_session
-		if active_session is None:
-			active_session = self
-			
-		super(MockSession, self).__init__()
-	
+class MockSession(Sequence):	
 	def __call__(self, api_func, args):
 		if self._index > len(self._states) - 1:
 			if len(self._states) == 0:
@@ -444,13 +437,13 @@ class MockSession(Sequence):
 			raise MockError("out of commands", api_func)
 			
 		return self._states[self._index](self, api_func, args)
-
+        
 	def make_active(self):
 		global active_session
-		
-		old_session = active_session
+
+		old = active_session
 		active_session = self
-		return old_session
+		return old
 		
 def validate(module, api_func, args):
 	if not isinstance(active_session, MockSession):
@@ -459,3 +452,21 @@ def validate(module, api_func, args):
 	return active_session(api_func, args)
 
 common.dispatcher = validate
+
+active_session = MockSession() 
+
+
+
+# Operations on the global active_session
+
+def add_command(func, args=(), return_val=None):
+    return active_session.add_command(func, args, return_val)
+    
+def add_sequence(state_list=[]):
+    return active_session.add_sequence(state_list)
+    
+def add_any_order(state_list=[]):
+    return active_session.add_any_order(state_list)
+    
+def add_error(func, args, exc):
+    return active_session.add_error(func, args, exc)
